<?php
/**
 * Composite usage of Growl PEAR::Log handler
 *
 * PHP versions 4 and 5
 *
 * @category  Logging
 * @package   Log
 * @author    Laurent Laville <pear@laurent-laville.org>
 * @copyright 2009 Laurent Laville
 * @license   http://www.opensource.org/licenses/bsd-license.php  New BSD License
 * @version   CVS: $Id:$
 * @link      http://pear.php.net/package/Log
 * @example   examples/growl_composite.php
 */
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<title>Log Growl composite examples</title>
<meta http-equiv="content-type" content="text/html; charset=iso-8859-1" />
</head>
<body>
<h1>Log Growl</h1>
<?php
require_once 'Log.php';
require_once 'Net/Growl.php';

$conf = array(
    'host' => $_SERVER['REMOTE_ADDR'],
    'password' => 'mamasam'
);
if (version_compare(phpversion(), '5.0.0', '>=')) {
    $conf['port']     = Net_Growl::GNTP_PORT;
    $conf['protocol'] = 'tcp';
    // PHP5 version of Net_Growl writes debug trace directly into a text file 
    $conf['debug'] = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'netgrowl.log';
} else {
    $conf['port']     = GROWL_GNTP_PORT;
    $conf['protocol'] = 'tcp';
    // PHP4 version of Net_Growl must use a PEAR::Log instance
    $conf['debug'] = &Log::singleton('file', 'netgrowl.log', 'NetGrowl');
}

$file  = &Log::singleton('file', 'out.log', 'TEST');
$growl = &Log::singleton('growl', '', 'TEST', $conf);
if (isset($growl)) {
    error_reporting(E_ALL);
    $growl->registerErrorHandler();
    $growl->registerExceptionHandler();
}
echo '<pre>'; var_export($growl); echo '</pre>';

$composite = &Log::singleton('composite');
$composite->addChild($file);
$composite->addChild($growl);

$composite->log('This simple event will be logged to both handlers.');

$composite->log(array('message' => "Be carefull message"), PEAR_LOG_WARNING);

$var = array('i' => 10, 'j' => 20);
$composite->log(
    array(
        'message'  => var_export($var, true),
        'priority' => $growl->getGrowlPriorityValue('moderate'),
        'sticky'   => true
    )
);

// catch a PHP notice error (see registerErrorHandler() function)
print $var['foo'];

// conclude with specific PHP5 exception test cases
if (version_compare(phpversion(), '5.0.0', '>=')) {
    function test($arg)
    {
        throw new Exception('Test Exception');
    }

    try {
        test(array('Hello' => 'World'));
    } catch(Exception $e) {
        /* Log catchable exception */
        $composite->log($e, PEAR_LOG_ALERT);
    }

    throw new Exception('Uncaught Exception');

    echo 'not executed';
}
?>
</body>
</html>